@@ -293,6 +293,7 @@ def fetch_data():
     for satellite in r_satellites.json():
         if satellite['norad_cat_id']:
             norad_cat_id = satellite['norad_cat_id']
+            satellite.pop('sat_id', None)
             satellite.pop('decayed', None)
             satellite.pop('launched', None)
             satellite.pop('deployed', None)
@@ -300,7 +301,8 @@ def fetch_data():
             satellite.pop('operator', None)
             satellite.pop('countries', None)
             satellite.pop('telemetries', None)
-            satellite.pop('sat_id', None)
+            satellite.pop('updated', None)
+            satellite.pop('citation', None)
             satellite.pop('associated_satellites', None)
             try:
                 # Update Satellite
